# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.chart2 import AxisType as AxisType
    if hasattr(AxisType, '_constants') and isinstance(AxisType._constants, dict):
        AxisType._constants['__ooo_ns__'] = 'com.sun.star.chart2'
        AxisType._constants['__ooo_full_ns__'] = 'com.sun.star.chart2.AxisType'
        AxisType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global AxisTypeEnum
        ls = [f for f in dir(AxisType) if not callable(getattr(AxisType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(AxisType, name)
        AxisTypeEnum = IntEnum('AxisTypeEnum', _dict)
    build_enum()
else:
    from ...lo.chart2.axis_type import AxisType as AxisType

    class AxisTypeEnum(IntEnum):
        """
        Enum of Const Class AxisType

        """
        REALNUMBER = AxisType.REALNUMBER
        """
        the axis represent real numbers
        """
        PERCENT = AxisType.PERCENT
        """
        the axis represent real numbers in percent
        """
        CATEGORY = AxisType.CATEGORY
        """
        the axis represent discrete categories
        """
        SERIES = AxisType.SERIES
        """
        the axis shows the series names (z axis)
        """
        DATE = AxisType.DATE
        """
        the axis shows dates
        """

__all__ = ['AxisType', 'AxisTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbc import BestRowType as BestRowType
    if hasattr(BestRowType, '_constants') and isinstance(BestRowType._constants, dict):
        BestRowType._constants['__ooo_ns__'] = 'com.sun.star.sdbc'
        BestRowType._constants['__ooo_full_ns__'] = 'com.sun.star.sdbc.BestRowType'
        BestRowType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global BestRowTypeEnum
        ls = [f for f in dir(BestRowType) if not callable(getattr(BestRowType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(BestRowType, name)
        BestRowTypeEnum = IntEnum('BestRowTypeEnum', _dict)
    build_enum()
else:
    from ...lo.sdbc.best_row_type import BestRowType as BestRowType

    class BestRowTypeEnum(IntEnum):
        """
        Enum of Const Class BestRowType

        determines the type of the best row identifier.
        """
        UNKNOWN = BestRowType.UNKNOWN
        """
        indicates that the best row identifier may or may not be a pseudo-column.
        
        A possible value for the column PSEUDO_COLUMN in the com.sun.star.sdbc.XResultSet object returned by the method XDatabaseMetaData.getBestRowIdentifier().
        """
        NOT_PSEUDO = BestRowType.NOT_PSEUDO
        """
        indicates that the best row identifier is NOT a pseudo-column.
        
        A possible value for the column PSEUDO_COLUMN in the com.sun.star.sdbc.XResultSet object returned by the method XDatabaseMetaData.getBestRowIdentifier().
        """
        PSEUDO = BestRowType.PSEUDO
        """
        indicates that the best row identifier is a pseudo-column.
        
        A possible value for the column PSEUDO_COLUMN in the com.sun.star.sdbc.XResultSet object returned by the method XDatabaseMetaData.getBestRowIdentifier().
        """

__all__ = ['BestRowType', 'BestRowTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from ooo.oenv.env_const import UNO_NONE
import typing
from .property_state import PropertyState as PropertyState_c97b0c77


class PropertyValue(object):
    """
    Struct Class

    specifies a property value.

    See Also:
        `API PropertyValue <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1PropertyValue.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.PropertyValue'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.PropertyValue'
    """Literal Constant ``com.sun.star.beans.PropertyValue``"""

    def __init__(self, Name: typing.Optional[str] = '', Handle: typing.Optional[int] = 0, Value: typing.Optional[object] = None, State: typing.Optional[PropertyState_c97b0c77] = PropertyState_c97b0c77.DIRECT_VALUE) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Handle (int, optional): Handle value.
            Value (object, optional): Value value.
            State (PropertyState, optional): State value.
        """
        super().__init__()

        if isinstance(Name, PropertyValue):
            oth: PropertyValue = Name
            self.Name = oth.Name
            self.Handle = oth.Handle
            self.Value = oth.Value
            self.State = oth.State
            return

        kargs = {
            "Name": Name,
            "Handle": Handle,
            "Value": Value,
            "State": State,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._handle = kwargs["Handle"]
        self._value = kwargs["Value"]
        self._state = kwargs["State"]


    @property
    def Name(self) -> str:
        """
        specifies the name of the property.
        
        The name is unique within a sequence of PropertyValues. Upper and lower case are distinguished.
        """
        return self._name
    
    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Handle(self) -> int:
        """
        contains an implementation-specific handle for the property.
        
        It may be -1 if the implementation has no handle. If available it can be used for fast lookups.
        """
        return self._handle
    
    @Handle.setter
    def Handle(self, value: int) -> None:
        self._handle = value

    @property
    def Value(self) -> object:
        """
        contains the value of the property or VOID, if no value is available.
        """
        return self._value
    
    @Value.setter
    def Value(self, value: object) -> None:
        self._value = value

    @property
    def State(self) -> PropertyState_c97b0c77:
        """
        determines if the value comes from the object itself or from a default and if the value cannot be determined exactly.
        """
        return self._state
    
    @State.setter
    def State(self, value: PropertyState_c97b0c77) -> None:
        self._state = value


__all__ = ['PropertyValue']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .xsql_query_composer import XSQLQueryComposer as XSQLQueryComposer_dd370ce7

class XSQLQueryComposerFactory(XInterface_8f010a43):
    """
    is a factory for instances of service com.sun.star.sdb.SQLQueryComposer.

    See Also:
        `API XSQLQueryComposerFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposerFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XSQLQueryComposerFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XSQLQueryComposerFactory'

    @abstractmethod
    def createQueryComposer(self) -> 'XSQLQueryComposer_dd370ce7':
        """
        creates a new query composer.
        """

__all__ = ['XSQLQueryComposerFactory']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
import typing
from abc import abstractmethod
from .x_data_output_stream import XDataOutputStream as XDataOutputStream_d2f40caf
if typing.TYPE_CHECKING:
    from .x_persist_object import XPersistObject as XPersistObject_af2f0b79

class XObjectOutputStream(XDataOutputStream_d2f40caf):
    """
    stores XPersistObject implementations into the stream
    
    An implementation of the type XPersistObject uses this interface to write its internal state into a stream. Have a look there for the explanation of the concept.

    See Also:
        `API XObjectOutputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XObjectOutputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XObjectOutputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XObjectOutputStream'

    @abstractmethod
    def writeObject(self, Object: 'XPersistObject_af2f0b79') -> None:
        """
        writes an object to the stream.

        Raises:
            IOException: ``IOException``
        """

__all__ = ['XObjectOutputStream']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.x_property_change_listener import XPropertyChangeListener as XPropertyChangeListener_58e4105a

class XConfigManager(XInterface_8f010a43):
    """
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XConfigManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XConfigManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XConfigManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XConfigManager'

    @abstractmethod
    def addPropertyChangeListener(self, KeyName: str, Listener: 'XPropertyChangeListener_58e4105a') -> None:
        """
        add a listener to notify changes on well known variables inside the real implementation
        
        Listener can update his text values by calling XConfigManager.substituteVariables() again. If KeyName specifies a group of keys, the listener gets one notify for each subkey.
        """
    @abstractmethod
    def flush(self) -> None:
        """
        was designed for additional functionality for interface com.sun.star.registry.XSimpleRegistry and make no sense without that
        """
    @abstractmethod
    def removePropertyChangeListener(self, KeyName: str, Listener: 'XPropertyChangeListener_58e4105a') -> None:
        """
        remove a registered listener
        """
    @abstractmethod
    def substituteVariables(self, Text: str) -> str:
        """
        substitute variables (place holder) inside given parameter Text
        
        The value of Text is NOT changed.
        """

__all__ = ['XConfigManager']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.frame.app_dispatch_provider import AppDispatchProvider as AppDispatchProvider
from ...dyn.frame.auto_recovery import AutoRecovery as AutoRecovery
from ...dyn.frame.bibliography import Bibliography as Bibliography
from ...dyn.frame.border_widths import BorderWidths as BorderWidths
from ...dyn.frame.command_group import CommandGroup as CommandGroup
from ...dyn.frame.command_group import CommandGroupEnum as CommandGroupEnum
from ...dyn.frame.components import Components as Components
from ...dyn.frame.content_handler import ContentHandler as ContentHandler
from ...dyn.frame.content_handler_factory import ContentHandlerFactory as ContentHandlerFactory
from ...dyn.frame.control_command import ControlCommand as ControlCommand
from ...dyn.frame.control_event import ControlEvent as ControlEvent
from ...dyn.frame.controller import Controller as Controller
from ...dyn.frame.desktop import Desktop as Desktop
from ...dyn.frame.desktop_task import DesktopTask as DesktopTask
from ...dyn.frame.desktop_tasks import DesktopTasks as DesktopTasks
from ...dyn.frame.dispatch_descriptor import DispatchDescriptor as DispatchDescriptor
from ...dyn.frame.dispatch_helper import DispatchHelper as DispatchHelper
from ...dyn.frame.dispatch_information import DispatchInformation as DispatchInformation
from ...dyn.frame.dispatch_provider import DispatchProvider as DispatchProvider
from ...dyn.frame.dispatch_recorder import DispatchRecorder as DispatchRecorder
from ...dyn.frame.dispatch_recorder_supplier import DispatchRecorderSupplier as DispatchRecorderSupplier
from ...dyn.frame.dispatch_result_event import DispatchResultEvent as DispatchResultEvent
from ...dyn.frame.dispatch_result_state import DispatchResultState as DispatchResultState
from ...dyn.frame.dispatch_result_state import DispatchResultStateEnum as DispatchResultStateEnum
from ...dyn.frame.dispatch_statement import DispatchStatement as DispatchStatement
from ...dyn.frame.document_templates import DocumentTemplates as DocumentTemplates
from ...dyn.frame.double_initialization_exception import DoubleInitializationException as DoubleInitializationException
from ...dyn.frame.feature_state_event import FeatureStateEvent as FeatureStateEvent
from ...dyn.frame.frame import Frame as Frame
from ...dyn.frame.frame_action import FrameAction as FrameAction
from ...dyn.frame.frame_action_event import FrameActionEvent as FrameActionEvent
from ...dyn.frame.frame_control import FrameControl as FrameControl
from ...dyn.frame.frame_loader import FrameLoader as FrameLoader
from ...dyn.frame.frame_loader_factory import FrameLoaderFactory as FrameLoaderFactory
from ...dyn.frame.frame_search_flag import FrameSearchFlag as FrameSearchFlag
from ...dyn.frame.frame_search_flag import FrameSearchFlagEnum as FrameSearchFlagEnum
from ...dyn.frame.frames_container import FramesContainer as FramesContainer
from ...dyn.frame.global_event_broadcaster import GlobalEventBroadcaster as GlobalEventBroadcaster
from ...dyn.frame.illegal_argument_io_exception import IllegalArgumentIOException as IllegalArgumentIOException
from ...dyn.frame.infobar_type import InfobarType as InfobarType
from ...dyn.frame.infobar_type import InfobarTypeEnum as InfobarTypeEnum
from ...dyn.frame.layout_manager import LayoutManager as LayoutManager
from ...dyn.frame.layout_manager_events import LayoutManagerEvents as LayoutManagerEvents
from ...dyn.frame.layout_manager_events import LayoutManagerEventsEnum as LayoutManagerEventsEnum
from ...dyn.frame.media_type_detection_helper import MediaTypeDetectionHelper as MediaTypeDetectionHelper
from ...dyn.frame.module_manager import ModuleManager as ModuleManager
from ...dyn.frame.office_frame_loader import OfficeFrameLoader as OfficeFrameLoader
from ...dyn.frame.popup_menu_controller import PopupMenuController as PopupMenuController
from ...dyn.frame.popup_menu_controller_factory import PopupMenuControllerFactory as PopupMenuControllerFactory
from ...dyn.frame.protocol_handler import ProtocolHandler as ProtocolHandler
from ...dyn.frame.session_listener import SessionListener as SessionListener
from ...dyn.frame.session_manager import SessionManager as SessionManager
from ...dyn.frame.settings import Settings as Settings
from ...dyn.frame.start_module import StartModule as StartModule
from ...dyn.frame.statusbar_controller import StatusbarController as StatusbarController
from ...dyn.frame.statusbar_controller_factory import StatusbarControllerFactory as StatusbarControllerFactory
from ...dyn.frame.synchronous_frame_loader import SynchronousFrameLoader as SynchronousFrameLoader
from ...dyn.frame.task import Task as Task
from ...dyn.frame.task_creator import TaskCreator as TaskCreator
from ...dyn.frame.template_access import TemplateAccess as TemplateAccess
from ...dyn.frame.termination_veto_exception import TerminationVetoException as TerminationVetoException
from ...dyn.frame.title_changed_event import TitleChangedEvent as TitleChangedEvent
from ...dyn.frame.toolbar_controller import ToolbarController as ToolbarController
from ...dyn.frame.toolbar_controller_factory import ToolbarControllerFactory as ToolbarControllerFactory
from ...dyn.frame.transient_documents_document_content_factory import TransientDocumentsDocumentContentFactory as TransientDocumentsDocumentContentFactory
from ...dyn.frame.ui_command_description import UICommandDescription as UICommandDescription
from ...dyn.frame.unknown_module_exception import UnknownModuleException as UnknownModuleException
from ...dyn.frame.untitled_numbers_const import UntitledNumbersConst as UntitledNumbersConst
from ...dyn.frame.untitled_numbers_const import UntitledNumbersConstEnum as UntitledNumbersConstEnum
from ...dyn.frame.window_arrange import WindowArrange as WindowArrange
from ...dyn.frame.window_arrange import WindowArrangeEnum as WindowArrangeEnum
from ...dyn.frame.x_app_dispatch_provider import XAppDispatchProvider as XAppDispatchProvider
from ...dyn.frame.x_border_resize_listener import XBorderResizeListener as XBorderResizeListener
from ...dyn.frame.x_browse_history_registry import XBrowseHistoryRegistry as XBrowseHistoryRegistry
from ...dyn.frame.x_component_loader import XComponentLoader as XComponentLoader
from ...dyn.frame.x_component_registry import XComponentRegistry as XComponentRegistry
from ...dyn.frame.x_config_manager import XConfigManager as XConfigManager
from ...dyn.frame.x_control_notification_listener import XControlNotificationListener as XControlNotificationListener
from ...dyn.frame.x_controller import XController as XController
from ...dyn.frame.x_controller2 import XController2 as XController2
from ...dyn.frame.x_controller_border import XControllerBorder as XControllerBorder
from ...dyn.frame.x_desktop import XDesktop as XDesktop
from ...dyn.frame.x_desktop2 import XDesktop2 as XDesktop2
from ...dyn.frame.x_desktop_task import XDesktopTask as XDesktopTask
from ...dyn.frame.x_dispatch import XDispatch as XDispatch
from ...dyn.frame.x_dispatch_helper import XDispatchHelper as XDispatchHelper
from ...dyn.frame.x_dispatch_information_provider import XDispatchInformationProvider as XDispatchInformationProvider
from ...dyn.frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider
from ...dyn.frame.x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception
from ...dyn.frame.x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor
from ...dyn.frame.x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder
from ...dyn.frame.x_dispatch_recorder_supplier import XDispatchRecorderSupplier as XDispatchRecorderSupplier
from ...dyn.frame.x_dispatch_result_listener import XDispatchResultListener as XDispatchResultListener
from ...dyn.frame.x_document_templates import XDocumentTemplates as XDocumentTemplates
from ...dyn.frame.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
from ...dyn.frame.x_filter_detect import XFilterDetect as XFilterDetect
from ...dyn.frame.x_frame import XFrame as XFrame
from ...dyn.frame.x_frame2 import XFrame2 as XFrame2
from ...dyn.frame.x_frame_action_listener import XFrameActionListener as XFrameActionListener
from ...dyn.frame.x_frame_loader import XFrameLoader as XFrameLoader
from ...dyn.frame.x_frame_loader_query import XFrameLoaderQuery as XFrameLoaderQuery
from ...dyn.frame.x_frame_set_model import XFrameSetModel as XFrameSetModel
from ...dyn.frame.x_frames import XFrames as XFrames
from ...dyn.frame.x_frames_supplier import XFramesSupplier as XFramesSupplier
from ...dyn.frame.x_global_event_broadcaster import XGlobalEventBroadcaster as XGlobalEventBroadcaster
from ...dyn.frame.x_infobar_provider import XInfobarProvider as XInfobarProvider
from ...dyn.frame.x_interceptor_info import XInterceptorInfo as XInterceptorInfo
from ...dyn.frame.x_layout_manager import XLayoutManager as XLayoutManager
from ...dyn.frame.x_layout_manager2 import XLayoutManager2 as XLayoutManager2
from ...dyn.frame.x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster
from ...dyn.frame.x_layout_manager_listener import XLayoutManagerListener as XLayoutManagerListener
from ...dyn.frame.x_load_event_listener import XLoadEventListener as XLoadEventListener
from ...dyn.frame.x_loadable import XLoadable as XLoadable
from ...dyn.frame.x_loader_factory import XLoaderFactory as XLoaderFactory
from ...dyn.frame.x_menu_bar_acceptor import XMenuBarAcceptor as XMenuBarAcceptor
from ...dyn.frame.x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor
from ...dyn.frame.x_model import XModel as XModel
from ...dyn.frame.x_model2 import XModel2 as XModel2
from ...dyn.frame.x_model3 import XModel3 as XModel3
from ...dyn.frame.x_module import XModule as XModule
from ...dyn.frame.x_module_manager import XModuleManager as XModuleManager
from ...dyn.frame.x_module_manager2 import XModuleManager2 as XModuleManager2
from ...dyn.frame.x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch
from ...dyn.frame.x_popup_menu_controller import XPopupMenuController as XPopupMenuController
from ...dyn.frame.x_recordable_dispatch import XRecordableDispatch as XRecordableDispatch
from ...dyn.frame.x_session_manager_client import XSessionManagerClient as XSessionManagerClient
from ...dyn.frame.x_session_manager_listener import XSessionManagerListener as XSessionManagerListener
from ...dyn.frame.x_session_manager_listener2 import XSessionManagerListener2 as XSessionManagerListener2
from ...dyn.frame.x_status_listener import XStatusListener as XStatusListener
from ...dyn.frame.x_statusbar_controller import XStatusbarController as XStatusbarController
from ...dyn.frame.x_storable import XStorable as XStorable
from ...dyn.frame.x_storable2 import XStorable2 as XStorable2
from ...dyn.frame.x_sub_toolbar_controller import XSubToolbarController as XSubToolbarController
from ...dyn.frame.x_synchronous_dispatch import XSynchronousDispatch as XSynchronousDispatch
from ...dyn.frame.x_synchronous_frame_loader import XSynchronousFrameLoader as XSynchronousFrameLoader
from ...dyn.frame.x_task import XTask as XTask
from ...dyn.frame.x_tasks_supplier import XTasksSupplier as XTasksSupplier
from ...dyn.frame.x_terminate_listener import XTerminateListener as XTerminateListener
from ...dyn.frame.x_terminate_listener2 import XTerminateListener2 as XTerminateListener2
from ...dyn.frame.x_title import XTitle as XTitle
from ...dyn.frame.x_title_change_broadcaster import XTitleChangeBroadcaster as XTitleChangeBroadcaster
from ...dyn.frame.x_title_change_listener import XTitleChangeListener as XTitleChangeListener
from ...dyn.frame.x_toolbar_controller import XToolbarController as XToolbarController
from ...dyn.frame.x_toolbar_controller_listener import XToolbarControllerListener as XToolbarControllerListener
from ...dyn.frame.x_transient_documents_document_content_factory import XTransientDocumentsDocumentContentFactory as XTransientDocumentsDocumentContentFactory
from ...dyn.frame.x_transient_documents_document_content_identifier_factory import XTransientDocumentsDocumentContentIdentifierFactory as XTransientDocumentsDocumentContentIdentifierFactory
from ...dyn.frame.xui_controller_factory import XUIControllerFactory as XUIControllerFactory
from ...dyn.frame.xui_controller_registration import XUIControllerRegistration as XUIControllerRegistration
from ...dyn.frame.x_untitled_numbers import XUntitledNumbers as XUntitledNumbers
from ...dyn.frame.x_url_list import XUrlList as XUrlList
from ...dyn.frame.x_window_arranger import XWindowArranger as XWindowArranger
from ...dyn.frame.the_auto_recovery import theAutoRecovery as theAutoRecovery
from ...dyn.frame.the_desktop import theDesktop as theDesktop
from ...dyn.frame.the_global_event_broadcaster import theGlobalEventBroadcaster as theGlobalEventBroadcaster
from ...dyn.frame.the_popup_menu_controller_factory import thePopupMenuControllerFactory as thePopupMenuControllerFactory
from ...dyn.frame.the_statusbar_controller_factory import theStatusbarControllerFactory as theStatusbarControllerFactory
from ...dyn.frame.the_toolbar_controller_factory import theToolbarControllerFactory as theToolbarControllerFactory
from ...dyn.frame.the_ui_command_description import theUICommandDescription as theUICommandDescription



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XConversionPropertyType(XInterface_8f010a43):
    """
    allows set and retrieve the property type of an entry in a conversion dictionary
    
    The property type must be one of com.sun.star.linguistic2.ConversionPropertyType
    
    **since**
    
        OOo 2.0

    See Also:
        `API XConversionPropertyType <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XConversionPropertyType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XConversionPropertyType'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XConversionPropertyType'

    @abstractmethod
    def getPropertyType(self, aLeftText: str, aRightText: str) -> int:
        """
        returns the property type for the specified entry.
        
        The conversion entry is specified by the pair ( aLeftText, aRightText ).

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    @abstractmethod
    def setPropertyType(self, aLeftText: str, aRightText: str, nPropertyType: int) -> None:
        """
        sets the property type for the specified entry.
        
        The conversion entry is specified by the pair ( aLeftText, aRightText ).

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """

__all__ = ['XConversionPropertyType']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.image
import typing
from abc import abstractproperty
from .image_map_object import ImageMapObject as ImageMapObject_d1e20c63
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e

class ImageMapCircleObject(ImageMapObject_d1e20c63):
    """
    Service Class

    this service describes a circular-shaped region inside a HTML image map.

    See Also:
        `API ImageMapCircleObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1image_1_1ImageMapCircleObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.image'
    __ooo_full_ns__: str = 'com.sun.star.image.ImageMapCircleObject'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Center(self) -> 'Point_5fb2085e':
        """
        This is the center point of the circle in pixels.
        """

    @abstractproperty
    def Radius(self) -> int:
        """
        This is the radius of the circle in pixels.
        """



__all__ = ['ImageMapCircleObject']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_menu_bar import XMenuBar as XMenuBar_7a040956
    from .x_top_window_listener import XTopWindowListener as XTopWindowListener_efc20d9d

class XTopWindow(XInterface_8f010a43):
    """
    manages the functionality specific for a top window.

    See Also:
        `API XTopWindow <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XTopWindow'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XTopWindow'

    @abstractmethod
    def addTopWindowListener(self, xListener: 'XTopWindowListener_efc20d9d') -> None:
        """
        adds the specified top window listener to receive window events from this window.
        """
    @abstractmethod
    def removeTopWindowListener(self, xListener: 'XTopWindowListener_efc20d9d') -> None:
        """
        removes the specified top window listener so that it no longer receives window events from this window.
        """
    @abstractmethod
    def setMenuBar(self, xMenu: 'XMenuBar_7a040956') -> None:
        """
        sets a menu bar.
        """
    @abstractmethod
    def toBack(self) -> None:
        """
        places this window at the bottom of the stacking order and makes the corresponding adjustment to other visible windows.
        """
    @abstractmethod
    def toFront(self) -> None:
        """
        places this window at the top of the stacking order and shows it in front of any other windows.
        """

__all__ = ['XTopWindow']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XIdlArray(XInterface_8f010a43):
    """
    Reflects an IDL sequence and provides dynamic access to instances of that sequence.
    
    This interface supports widening conversion when getting or setting elements.

    See Also:
        `API XIdlArray <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlArray.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlArray'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlArray'

    @abstractmethod
    def get(self, aArray: object, nIndex: int) -> object:
        """
        Returns element at given index.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.ArrayIndexOutOfBoundsException: ``ArrayIndexOutOfBoundsException``
        """
    @abstractmethod
    def getLen(self, array: object) -> int:
        """
        Returns the length of the given sequence.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def realloc(self, array: object, length: int) -> None:
        """
        Reallocates the length of the sequence instance.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def set(self, aArray: object, nIndex: int, aNewValue: object) -> None:
        """
        Sets a new value at given index.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.ArrayIndexOutOfBoundsException: ``ArrayIndexOutOfBoundsException``
        """

__all__ = ['XIdlArray']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.security
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.security import KeyUsage as KeyUsage
    if hasattr(KeyUsage, '_constants') and isinstance(KeyUsage._constants, dict):
        KeyUsage._constants['__ooo_ns__'] = 'com.sun.star.security'
        KeyUsage._constants['__ooo_full_ns__'] = 'com.sun.star.security.KeyUsage'
        KeyUsage._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global KeyUsageEnum
        ls = [f for f in dir(KeyUsage) if not callable(getattr(KeyUsage, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(KeyUsage, name)
        KeyUsageEnum = IntFlag('KeyUsageEnum', _dict)
    build_enum()
else:
    from ...lo.security.key_usage import KeyUsage as KeyUsage

    class KeyUsageEnum(IntFlag):
        """
        Enum of Const Class KeyUsage

        """
        DIGITAL_SIGNATURE = KeyUsage.DIGITAL_SIGNATURE
        NON_REPUDIATION = KeyUsage.NON_REPUDIATION
        KEY_ENCIPHERMENT = KeyUsage.KEY_ENCIPHERMENT
        DATA_ENCIPHERMENT = KeyUsage.DATA_ENCIPHERMENT
        KEY_AGREEMENT = KeyUsage.KEY_AGREEMENT
        KEY_CERT_SIGN = KeyUsage.KEY_CERT_SIGN
        CRL_SIGN = KeyUsage.CRL_SIGN

__all__ = ['KeyUsage', 'KeyUsageEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
import typing
from abc import abstractmethod
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_external_doc_link import XExternalDocLink as XExternalDocLink_ef5c0d60

class XExternalDocLinks(XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XNameAccess_e2ab0cf6):
    """
    Primary interface for the com.sun.star.sheet.ExternalDocLinks service.
    
    **since**
    
        OOo 3.1

    See Also:
        `API XExternalDocLinks <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLinks.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XExternalDocLinks'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XExternalDocLinks'

    @abstractmethod
    def addDocLink(self, aDocName: str) -> 'XExternalDocLink_ef5c0d60':
        """
        This method adds a new external document link by its URL, and returns its instance.
        
        If a document instance already exists for the specified URL, then that instance gets returned instead of creating a new one.
        """

__all__ = ['XExternalDocLinks']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbcx
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbcx import Privilege as Privilege
    if hasattr(Privilege, '_constants') and isinstance(Privilege._constants, dict):
        Privilege._constants['__ooo_ns__'] = 'com.sun.star.sdbcx'
        Privilege._constants['__ooo_full_ns__'] = 'com.sun.star.sdbcx.Privilege'
        Privilege._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global PrivilegeEnum
        ls = [f for f in dir(Privilege) if not callable(getattr(Privilege, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(Privilege, name)
        PrivilegeEnum = IntFlag('PrivilegeEnum', _dict)
    build_enum()
else:
    from ...lo.sdbcx.privilege import Privilege as Privilege

    class PrivilegeEnum(IntFlag):
        """
        Enum of Const Class Privilege

        defines a list of flags (bitmaps) which determines the access rights of a user or a user group.
        
        This list may grow in the future.
        """
        SELECT = Privilege.SELECT
        """
        indicates that a user is allowed to read the data.
        """
        INSERT = Privilege.INSERT
        """
        indicates that a user is allowed to insert new data.
        """
        UPDATE = Privilege.UPDATE
        """
        indicates that a user is allowed to update data.
        """
        DELETE = Privilege.DELETE
        """
        indicates that a user is allowed to delete data.
        """
        READ = Privilege.READ
        """
        indicates that a user is allowed to read the structure of a definition object.
        """
        CREATE = Privilege.CREATE
        """
        indicates that a user is allowed to create a definition object.
        """
        ALTER = Privilege.ALTER
        """
        indicates that a user is allowed to alter an existing object.
        """
        REFERENCE = Privilege.REFERENCE
        """
        indicates that a user is allowed to set foreign keys for a table.
        """
        DROP = Privilege.DROP
        """
        indicates that a user is allowed to drop a definition object.
        """

__all__ = ['Privilege', 'PrivilegeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.i18n import NativeNumberMode as NativeNumberMode
    if hasattr(NativeNumberMode, '_constants') and isinstance(NativeNumberMode._constants, dict):
        NativeNumberMode._constants['__ooo_ns__'] = 'com.sun.star.i18n'
        NativeNumberMode._constants['__ooo_full_ns__'] = 'com.sun.star.i18n.NativeNumberMode'
        NativeNumberMode._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global NativeNumberModeEnum
        ls = [f for f in dir(NativeNumberMode) if not callable(getattr(NativeNumberMode, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(NativeNumberMode, name)
        NativeNumberModeEnum = IntEnum('NativeNumberModeEnum', _dict)
    build_enum()
else:
    from ...lo.i18n.native_number_mode import NativeNumberMode as NativeNumberMode

    class NativeNumberModeEnum(IntEnum):
        """
        Enum of Const Class NativeNumberMode

        Constants to use with XExtendedCalendar.getDisplayString() and the XNativeNumberSupplier methods.
        
        The constants have different meanings if used with different locales. However, NATNUM1 always tries to convert to a string matching the native number mode of the corresponding locale.
        
        Where available, the corresponding Microsoft Excel (tm) DBNum number format code modifier is listed.
        
        Modifiers supported by XExtendedCalendar.getDisplayString() are marked with CAL: for the specific language and the corresponding DBNum modifier and the NatNum values used for Y/M/D are listed
        
        **since**
        
            OOo 1.1.2
        """
        NATNUM0 = NativeNumberMode.NATNUM0
        """
        Transliteration to ASCII Arabic digits.
        
        Try to convert any native number string to ASCII. If already ASCII it remains ASCII.
        """
        NATNUM1 = NativeNumberMode.NATNUM1
        """
        Transliteration in
        Chinese: Chinese lower case characters; CAL: 1/7/7 [DBNum1]
        Japanese: short Kanji characters [DBNum1]; CAL: 1/4/4 [DBNum1]
        Korean: Korean lower case characters [DBNum1]; CAL: 1/7/7 [DBNum1]
        Hebrew: Hebrew characters
        Arabic: Arabic-Indic characters
        Thai: Thai characters
        Hindi: Indic-Devanagari characters
        Odia: Odia (Oriya) characters
        Marathi: Indic-Devanagari characters
        Bengali: Bengali characters
        Punjabi: Punjabi (Gurmukhi) characters
        Gujarati: Gujarati characters
        Tamil: Tamil characters
        Telugu: Telugu characters
        Kannada: Kannada characters
        Malayalam: Malayalam characters
        Lao: Lao characters
        Tibetan: Tibetan characters
        Burmese: Burmese (Myanmar) characters
        Khmer: Khmer (Cambodian) characters
        Mongolian: Mongolian characters
        Nepali: Indic-Devanagari characters
        Dzongkha: Tibetan characters
        Farsi: East Arabic-Indic characters
        Church Slavic: Cyrillic characters.
        """
        NATNUM2 = NativeNumberMode.NATNUM2
        """
        Transliteration in
        Chinese: Chinese upper case characters; CAL: 2/8/8 [DBNum2]
        Japanese: traditional Kanji characters; CAL: 2/5/5 [DBNum2]
        Korean: Korean upper case characters [DBNum2]; CAL: 2/8/8 [DBNum2]
        Hebrew: Hebrew numbering.
        """
        NATNUM3 = NativeNumberMode.NATNUM3
        """
        Transliteration in
        Chinese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3]
        Japanese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3]
        Korean: fullwidth Arabic digits [DBNum3]; CAL: 3/3/3 [DBNum3].
        """
        NATNUM4 = NativeNumberMode.NATNUM4
        """
        Transliteration in
        Chinese: lower case text [DBNum1]
        Japanese: modern long Kanji text [DBNum2]
        Korean: formal lower case text.
        """
        NATNUM5 = NativeNumberMode.NATNUM5
        """
        Transliteration in
        Chinese: Chinese upper case text [DBNum2]
        Japanese: traditional long Kanji text [DBNum3]
        Korean: formal upper case text.
        """
        NATNUM6 = NativeNumberMode.NATNUM6
        """
        Transliteration in
        Chinese: fullwidth text [DBNum3]
        Japanese: fullwidth text
        Korean: fullwidth text.
        """
        NATNUM7 = NativeNumberMode.NATNUM7
        """
        Transliteration in
        Chinese: short lower case text
        Japanese: modern short Kanji text
        Korean: informal lower case text.
        """
        NATNUM8 = NativeNumberMode.NATNUM8
        """
        Transliteration in
        Chinese: short upper case text
        Japanese: traditional short Kanji text [DBNum4]
        Korean: informal upper case text.
        """
        NATNUM9 = NativeNumberMode.NATNUM9
        """
        Transliteration in
        Korean: Hangul characters.
        """
        NATNUM10 = NativeNumberMode.NATNUM10
        """
        Transliteration in
        Korean: formal Hangul text [DBNum4]; CAL: 9/11/11 [DBNum4].
        """
        NATNUM11 = NativeNumberMode.NATNUM11
        """
        Transliteration in
        Korean: informal Hangul text.
        """
        NATNUM12 = NativeNumberMode.NATNUM12
        """
        Transliteration to cardinal number names (one, two, three, ...), ordinal number names (first, second, third, ...), ordinal indicators (1st, 2nd, 3rd, ...), etc.
        
        Uses NatNum params string
        """

__all__ = ['NativeNumberMode', 'NativeNumberModeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from abc import abstractmethod
from .x_dialog import XDialog as XDialog_709d08fc

class XDialog2(XDialog_709d08fc):
    """
    Makes it possible to end a dialog and set a help id.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XDialog2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDialog2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XDialog2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XDialog2'

    @abstractmethod
    def endDialog(self, Result: int) -> None:
        """
        hides the dialog and then causes XDialog.execute() to return with the given result value.
        """
    @abstractmethod
    def setHelpId(self, Id: str) -> None:
        """
        sets the help id so that the standard help button action will show the appropriate help page.
        """

__all__ = ['XDialog2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from .generic_draw_page import GenericDrawPage as GenericDrawPage_fd960dbc
from .x_master_page_target import XMasterPageTarget as XMasterPageTarget_1a670e9c
from ..form.x_forms_supplier import XFormsSupplier as XFormsSupplier_c8f90c6f

class DrawPage(GenericDrawPage_fd960dbc, XMasterPageTarget_1a670e9c, XFormsSupplier_c8f90c6f):
    """
    Service Class

    This service specifies a page for the actual draw pages to contain the drawings.

    See Also:
        `API DrawPage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1DrawPage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.DrawPage'
    __ooo_type_name__: str = 'service'



__all__ = ['DrawPage']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt


class FontWeight(object):
    """
    Const Class

    These values are used to specify whether a font is thin or bold.
    
    They may be expanded in future versions.

    See Also:
        `API FontWeight <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontWeight.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FontWeight'
    __ooo_type_name__: str = 'const'

    DONTKNOW = 0.0
    """
    The font weight is not specified/known.
    """
    THIN = 50.0
    """
    specifies a 50% font weight.
    """
    ULTRALIGHT = 60.0
    """
    specifies a 60% font weight.
    """
    LIGHT = 75.0
    """
    specifies a 75% font weight.
    """
    SEMILIGHT = 90.0
    """
    specifies a 90% font weight.
    """
    NORMAL = 100.0
    """
    specifies a normal font weight.
    """
    SEMIBOLD = 110.0
    """
    specifies a 110% font weight.
    """
    BOLD = 150.0
    """
    specifies a 150% font weight.
    """
    ULTRABOLD = 175.0
    """
    specifies a 175% font weight.
    """
    BLACK = 200.0
    """
    specifies a 200% font weight.
    """

__all__ = ['FontWeight']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from enum import Enum


class CellDeleteMode(Enum):
    """
    Enum Class

    

    See Also:
        `API CellDeleteMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.CellDeleteMode'
    __ooo_type_name__: str = 'enum'

    COLUMNS = 'COLUMNS'
    """
    entire columns to the right of the deleted cells are moved left.
    
    entire columns to the right of the inserted cells are moved right.
    """
    LEFT = 'LEFT'
    """
    selects the left border.
    
    the cells to the right of the deleted cells are moved left.
    """
    NONE = 'NONE'
    """
    no cells are moved.
    
    sheet is not linked.
    
    new values are used without changes.
    
    nothing is calculated.
    
    nothing is imported.
    
    no condition is specified.
    """
    ROWS = 'ROWS'
    """
    entire rows below the deleted cells are moved up.
    
    entire rows below the inserted cells are moved down.
    """
    UP = 'UP'
    """
    the cells below the deleted cells are moved up.
    """

__all__ = ['CellDeleteMode']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.inspection
import typing
from abc import abstractmethod
from .x_string_representation import XStringRepresentation as XStringRepresentation_939311e6
if typing.TYPE_CHECKING:
    from ..script.x_type_converter import XTypeConverter as XTypeConverter_e48b0d4f

class StringRepresentation(XStringRepresentation_939311e6):
    """
    Service Class


    See Also:
        `API StringRepresentation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1inspection_1_1StringRepresentation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.StringRepresentation'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, TypeConverter: 'XTypeConverter_e48b0d4f') -> None:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def createConstant(self, TypeConverter: 'XTypeConverter_e48b0d4f', Constant: str, Values: 'typing.Tuple[str, ...]') -> None:
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """


__all__ = ['StringRepresentation']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.3
from enum import Enum


class FontSlant(Enum):
    """
    Enum Class

    

    See Also:
        `API FontSlant <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt.html#a362a86d3ebca4a201d13bc3e7b94340e>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FontSlant'
    __ooo_type_name__: str = 'enum'

    DONTKNOW = 'DONTKNOW'
    """
    specifies a font with an unknown slant.
    
    specifies that the menu item type is unknown.
    """
    ITALIC = 'ITALIC'
    """
    specifies an italic font (slant designed into the font).
    """
    NONE = 'NONE'
    """
    specifies a font without slant.
    """
    OBLIQUE = 'OBLIQUE'
    """
    specifies an oblique font (slant not designed into the font).
    """
    REVERSE_ITALIC = 'REVERSE_ITALIC'
    """
    specifies a reverse italic font (slant designed into the font).
    """
    REVERSE_OBLIQUE = 'REVERSE_OBLIQUE'
    """
    specifies a reverse oblique font (slant not designed into the font).
    """

__all__ = ['FontSlant']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.text import TextMarkupType as TextMarkupType
    if hasattr(TextMarkupType, '_constants') and isinstance(TextMarkupType._constants, dict):
        TextMarkupType._constants['__ooo_ns__'] = 'com.sun.star.text'
        TextMarkupType._constants['__ooo_full_ns__'] = 'com.sun.star.text.TextMarkupType'
        TextMarkupType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global TextMarkupTypeEnum
        ls = [f for f in dir(TextMarkupType) if not callable(getattr(TextMarkupType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(TextMarkupType, name)
        TextMarkupTypeEnum = IntEnum('TextMarkupTypeEnum', _dict)
    build_enum()
else:
    from ...lo.text.text_markup_type import TextMarkupType as TextMarkupType

    class TextMarkupTypeEnum(IntEnum):
        """
        Enum of Const Class TextMarkupType

        Constants to specify the type of text markup.
        
        These constants are used with XTextMarkup.commitTextMarkup()
        
        **since**
        
            OOo 2.3
        """
        SPELLCHECK = TextMarkupType.SPELLCHECK
        """
        Markup originates from spell checking.
        """
        PROOFREADING = TextMarkupType.PROOFREADING
        """
        Markup originates from proofreading.
        
        **since**
        
            OOo 3.0.1
        """
        SMARTTAG = TextMarkupType.SMARTTAG
        """
        Markup originates from smart tag checking.
        """
        SENTENCE = TextMarkupType.SENTENCE
        """
        Markup originates from proofreading An invisible markup type used in proofreading API calls.
        
        **since**
        
            OOo 3.0.1
        """
        TRACK_CHANGE_INSERTION = TextMarkupType.TRACK_CHANGE_INSERTION
        """
        Markups originates from change tracking.
        
        **since**
        
            OOo 3.3
        """
        TRACK_CHANGE_DELETION = TextMarkupType.TRACK_CHANGE_DELETION
        TRACK_CHANGE_FORMATCHANGE = TextMarkupType.TRACK_CHANGE_FORMATCHANGE

__all__ = ['TextMarkupType', 'TextMarkupTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n


class NativeNumberMode(object):
    """
    Const Class

    Constants to use with XExtendedCalendar.getDisplayString() and the XNativeNumberSupplier methods.
    
    The constants have different meanings if used with different locales. However, NATNUM1 always tries to convert to a string matching the native number mode of the corresponding locale.
    
    Where available, the corresponding Microsoft Excel (tm) DBNum number format code modifier is listed.
    
    Modifiers supported by XExtendedCalendar.getDisplayString() are marked with CAL: for the specific language and the corresponding DBNum modifier and the NatNum values used for Y/M/D are listed
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API NativeNumberMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1NativeNumberMode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.NativeNumberMode'
    __ooo_type_name__: str = 'const'

    NATNUM0 = 0
    """
    Transliteration to ASCII Arabic digits.
    
    Try to convert any native number string to ASCII. If already ASCII it remains ASCII.
    """
    NATNUM1 = 1
    """
    Transliteration in
    Chinese: Chinese lower case characters; CAL: 1/7/7 [DBNum1]
    Japanese: short Kanji characters [DBNum1]; CAL: 1/4/4 [DBNum1]
    Korean: Korean lower case characters [DBNum1]; CAL: 1/7/7 [DBNum1]
    Hebrew: Hebrew characters
    Arabic: Arabic-Indic characters
    Thai: Thai characters
    Hindi: Indic-Devanagari characters
    Odia: Odia (Oriya) characters
    Marathi: Indic-Devanagari characters
    Bengali: Bengali characters
    Punjabi: Punjabi (Gurmukhi) characters
    Gujarati: Gujarati characters
    Tamil: Tamil characters
    Telugu: Telugu characters
    Kannada: Kannada characters
    Malayalam: Malayalam characters
    Lao: Lao characters
    Tibetan: Tibetan characters
    Burmese: Burmese (Myanmar) characters
    Khmer: Khmer (Cambodian) characters
    Mongolian: Mongolian characters
    Nepali: Indic-Devanagari characters
    Dzongkha: Tibetan characters
    Farsi: East Arabic-Indic characters
    Church Slavic: Cyrillic characters.
    """
    NATNUM2 = 2
    """
    Transliteration in
    Chinese: Chinese upper case characters; CAL: 2/8/8 [DBNum2]
    Japanese: traditional Kanji characters; CAL: 2/5/5 [DBNum2]
    Korean: Korean upper case characters [DBNum2]; CAL: 2/8/8 [DBNum2]
    Hebrew: Hebrew numbering.
    """
    NATNUM3 = 3
    """
    Transliteration in
    Chinese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3]
    Japanese: fullwidth Arabic digits; CAL: 3/3/3 [DBNum3]
    Korean: fullwidth Arabic digits [DBNum3]; CAL: 3/3/3 [DBNum3].
    """
    NATNUM4 = 4
    """
    Transliteration in
    Chinese: lower case text [DBNum1]
    Japanese: modern long Kanji text [DBNum2]
    Korean: formal lower case text.
    """
    NATNUM5 = 5
    """
    Transliteration in
    Chinese: Chinese upper case text [DBNum2]
    Japanese: traditional long Kanji text [DBNum3]
    Korean: formal upper case text.
    """
    NATNUM6 = 6
    """
    Transliteration in
    Chinese: fullwidth text [DBNum3]
    Japanese: fullwidth text
    Korean: fullwidth text.
    """
    NATNUM7 = 7
    """
    Transliteration in
    Chinese: short lower case text
    Japanese: modern short Kanji text
    Korean: informal lower case text.
    """
    NATNUM8 = 8
    """
    Transliteration in
    Chinese: short upper case text
    Japanese: traditional short Kanji text [DBNum4]
    Korean: informal upper case text.
    """
    NATNUM9 = 9
    """
    Transliteration in
    Korean: Hangul characters.
    """
    NATNUM10 = 10
    """
    Transliteration in
    Korean: formal Hangul text [DBNum4]; CAL: 9/11/11 [DBNum4].
    """
    NATNUM11 = 11
    """
    Transliteration in
    Korean: informal Hangul text.
    """
    NATNUM12 = 12
    """
    Transliteration to cardinal number names (one, two, three, ...), ordinal number names (first, second, third, ...), ordinal indicators (1st, 2nd, 3rd, ...), etc.
    
    Uses NatNum params string
    """

__all__ = ['NativeNumberMode']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.rendering import FloatingPointBitmapFormat as FloatingPointBitmapFormat
    if hasattr(FloatingPointBitmapFormat, '_constants') and isinstance(FloatingPointBitmapFormat._constants, dict):
        FloatingPointBitmapFormat._constants['__ooo_ns__'] = 'com.sun.star.rendering'
        FloatingPointBitmapFormat._constants['__ooo_full_ns__'] = 'com.sun.star.rendering.FloatingPointBitmapFormat'
        FloatingPointBitmapFormat._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global FloatingPointBitmapFormatEnum
        ls = [f for f in dir(FloatingPointBitmapFormat) if not callable(getattr(FloatingPointBitmapFormat, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(FloatingPointBitmapFormat, name)
        FloatingPointBitmapFormatEnum = IntEnum('FloatingPointBitmapFormatEnum', _dict)
    build_enum()
else:
    from ...lo.rendering.floating_point_bitmap_format import FloatingPointBitmapFormat as FloatingPointBitmapFormat

    class FloatingPointBitmapFormatEnum(IntEnum):
        """
        Enum of Const Class FloatingPointBitmapFormat

        This structure describes format of a floating point bitmap.
        
        **since**
        
            OOo 2.0
        """
        HALFFLOAT = FloatingPointBitmapFormat.HALFFLOAT
        """
        Half-float format.
        
        The color components are stored in the half-float format, i.e. in a 16 bit value, with 5 bit exponent, 10 bit mantissa and a sign bit. See also OpenEXR for a format employing half-floats.
        """
        FLOAT = FloatingPointBitmapFormat.FLOAT
        """
        IEEE float format.
        
        The color components are stored in the IEEE single-precision floating point format, i.e. in a 32 bit value, with 8 bit exponent, 23 bit mantissa and a sign bit.
        """
        DOUBLE = FloatingPointBitmapFormat.DOUBLE
        """
        IEEE double format.
        
        The color components are stored in the IEEE double-precision floating point format, i.e. in a 64 bit value, with 16 bit exponent, 47 bit mantissa and a sign bit.
        """

__all__ = ['FloatingPointBitmapFormat', 'FloatingPointBitmapFormatEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.i18n.TransliterationModulesNew import (CharToNumHangul_ko, CharToNumLower_ko, CharToNumLower_zh_CN, CharToNumLower_zh_TW, CharToNumUpper_ko, CharToNumUpper_zh_CN, CharToNumUpper_zh_TW, END_OF_MODULE, FULLWIDTH_HALFWIDTH, HALFWIDTH_FULLWIDTH, HIRAGANA_KATAKANA, IGNORE_CASE, IGNORE_KANA, IGNORE_WIDTH, IgnoreBaFa_ja_JP, IgnoreHyuByu_ja_JP, IgnoreIandEfollowedByYa_ja_JP, IgnoreIterationMark_ja_JP, IgnoreKiKuFollowedBySa_ja_JP, IgnoreMiddleDot_ja_JP, IgnoreMinusSign_ja_JP, IgnoreProlongedSoundMark_ja_JP, IgnoreSeZe_ja_JP, IgnoreSeparator_ja_JP, IgnoreSize_ja_JP, IgnoreSpace_ja_JP, IgnoreTiJi_ja_JP, IgnoreTraditionalKana_ja_JP, IgnoreTraditionalKanji_ja_JP, IgnoreZiZu_ja_JP, KATAKANA_HIRAGANA, LOWERCASE_UPPERCASE, LargeToSmall_ja_JP, NumToCharFullwidth, NumToCharHangul_ko, NumToCharKanjiShort_ja_JP, NumToCharLower_ko, NumToCharLower_zh_CN, NumToCharLower_zh_TW, NumToCharUpper_ko, NumToCharUpper_zh_CN, NumToCharUpper_zh_TW, NumToTextFormalHangul_ko, NumToTextFormalLower_ko, NumToTextFormalUpper_ko, NumToTextInformalHangul_ko, NumToTextInformalLower_ko, NumToTextInformalUpper_ko, NumToTextLower_zh_CN, NumToTextLower_zh_TW, NumToTextUpper_zh_CN, NumToTextUpper_zh_TW, SmallToLarge_ja_JP, TextToNumFormalHangul_ko, TextToNumFormalLower_ko, TextToNumFormalUpper_ko, TextToNumInformalHangul_ko, TextToNumInformalLower_ko, TextToNumInformalUpper_ko, TextToNumLower_zh_CN, TextToNumLower_zh_TW, TextToNumUpper_zh_CN, TextToNumUpper_zh_TW, UPPERCASE_LOWERCASE)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.i18n.TransliterationModulesNew Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.i18n",
            "__ooo_full_ns__": "com.sun.star.i18n.TransliterationModulesNew",
            "__ooo_type_name__": "enum",
            "CharToNumHangul_ko": CharToNumHangul_ko,
            "CharToNumLower_ko": CharToNumLower_ko,
            "CharToNumLower_zh_CN": CharToNumLower_zh_CN,
            "CharToNumLower_zh_TW": CharToNumLower_zh_TW,
            "CharToNumUpper_ko": CharToNumUpper_ko,
            "CharToNumUpper_zh_CN": CharToNumUpper_zh_CN,
            "CharToNumUpper_zh_TW": CharToNumUpper_zh_TW,
            "END_OF_MODULE": END_OF_MODULE,
            "FULLWIDTH_HALFWIDTH": FULLWIDTH_HALFWIDTH,
            "HALFWIDTH_FULLWIDTH": HALFWIDTH_FULLWIDTH,
            "HIRAGANA_KATAKANA": HIRAGANA_KATAKANA,
            "IGNORE_CASE": IGNORE_CASE,
            "IGNORE_KANA": IGNORE_KANA,
            "IGNORE_WIDTH": IGNORE_WIDTH,
            "IgnoreBaFa_ja_JP": IgnoreBaFa_ja_JP,
            "IgnoreHyuByu_ja_JP": IgnoreHyuByu_ja_JP,
            "IgnoreIandEfollowedByYa_ja_JP": IgnoreIandEfollowedByYa_ja_JP,
            "IgnoreIterationMark_ja_JP": IgnoreIterationMark_ja_JP,
            "IgnoreKiKuFollowedBySa_ja_JP": IgnoreKiKuFollowedBySa_ja_JP,
            "IgnoreMiddleDot_ja_JP": IgnoreMiddleDot_ja_JP,
            "IgnoreMinusSign_ja_JP": IgnoreMinusSign_ja_JP,
            "IgnoreProlongedSoundMark_ja_JP": IgnoreProlongedSoundMark_ja_JP,
            "IgnoreSeZe_ja_JP": IgnoreSeZe_ja_JP,
            "IgnoreSeparator_ja_JP": IgnoreSeparator_ja_JP,
            "IgnoreSize_ja_JP": IgnoreSize_ja_JP,
            "IgnoreSpace_ja_JP": IgnoreSpace_ja_JP,
            "IgnoreTiJi_ja_JP": IgnoreTiJi_ja_JP,
            "IgnoreTraditionalKana_ja_JP": IgnoreTraditionalKana_ja_JP,
            "IgnoreTraditionalKanji_ja_JP": IgnoreTraditionalKanji_ja_JP,
            "IgnoreZiZu_ja_JP": IgnoreZiZu_ja_JP,
            "KATAKANA_HIRAGANA": KATAKANA_HIRAGANA,
            "LOWERCASE_UPPERCASE": LOWERCASE_UPPERCASE,
            "LargeToSmall_ja_JP": LargeToSmall_ja_JP,
            "NumToCharFullwidth": NumToCharFullwidth,
            "NumToCharHangul_ko": NumToCharHangul_ko,
            "NumToCharKanjiShort_ja_JP": NumToCharKanjiShort_ja_JP,
            "NumToCharLower_ko": NumToCharLower_ko,
            "NumToCharLower_zh_CN": NumToCharLower_zh_CN,
            "NumToCharLower_zh_TW": NumToCharLower_zh_TW,
            "NumToCharUpper_ko": NumToCharUpper_ko,
            "NumToCharUpper_zh_CN": NumToCharUpper_zh_CN,
            "NumToCharUpper_zh_TW": NumToCharUpper_zh_TW,
            "NumToTextFormalHangul_ko": NumToTextFormalHangul_ko,
            "NumToTextFormalLower_ko": NumToTextFormalLower_ko,
            "NumToTextFormalUpper_ko": NumToTextFormalUpper_ko,
            "NumToTextInformalHangul_ko": NumToTextInformalHangul_ko,
            "NumToTextInformalLower_ko": NumToTextInformalLower_ko,
            "NumToTextInformalUpper_ko": NumToTextInformalUpper_ko,
            "NumToTextLower_zh_CN": NumToTextLower_zh_CN,
            "NumToTextLower_zh_TW": NumToTextLower_zh_TW,
            "NumToTextUpper_zh_CN": NumToTextUpper_zh_CN,
            "NumToTextUpper_zh_TW": NumToTextUpper_zh_TW,
            "SmallToLarge_ja_JP": SmallToLarge_ja_JP,
            "TextToNumFormalHangul_ko": TextToNumFormalHangul_ko,
            "TextToNumFormalLower_ko": TextToNumFormalLower_ko,
            "TextToNumFormalUpper_ko": TextToNumFormalUpper_ko,
            "TextToNumInformalHangul_ko": TextToNumInformalHangul_ko,
            "TextToNumInformalLower_ko": TextToNumInformalLower_ko,
            "TextToNumInformalUpper_ko": TextToNumInformalUpper_ko,
            "TextToNumLower_zh_CN": TextToNumLower_zh_CN,
            "TextToNumLower_zh_TW": TextToNumLower_zh_TW,
            "TextToNumUpper_zh_CN": TextToNumUpper_zh_CN,
            "TextToNumUpper_zh_TW": TextToNumUpper_zh_TW,
            "UPPERCASE_LOWERCASE": UPPERCASE_LOWERCASE,
        }
        result = type('TransliterationModulesNew', (object,), _dict)
        return result

    TransliterationModulesNew = _get_enum()
else:
    from ...lo.i18n.transliteration_modules_new import TransliterationModulesNew as TransliterationModulesNew

__all__ = ['TransliterationModulesNew']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.presentation
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.presentation import EffectCommands as EffectCommands
    if hasattr(EffectCommands, '_constants') and isinstance(EffectCommands._constants, dict):
        EffectCommands._constants['__ooo_ns__'] = 'com.sun.star.presentation'
        EffectCommands._constants['__ooo_full_ns__'] = 'com.sun.star.presentation.EffectCommands'
        EffectCommands._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global EffectCommandsEnum
        ls = [f for f in dir(EffectCommands) if not callable(getattr(EffectCommands, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(EffectCommands, name)
        EffectCommandsEnum = IntEnum('EffectCommandsEnum', _dict)
    build_enum()
else:
    from ...lo.presentation.effect_commands import EffectCommands as EffectCommands

    class EffectCommandsEnum(IntEnum):
        """
        Enum of Const Class EffectCommands

        """
        CUSTOM = EffectCommands.CUSTOM
        """
        the command is user defined
        """
        VERB = EffectCommands.VERB
        """
        the command is an OLE verb.
        
        Required parameters are \"Verb\" of type long that specifies the verb to execute.
        """
        PLAY = EffectCommands.PLAY
        """
        the command starts playing on a media object.
        
        Optional parameters are \"MediaTime\" of type double that specifies the start time in milliseconds. If not given, play continues at last position known.
        """
        TOGGLEPAUSE = EffectCommands.TOGGLEPAUSE
        """
        the command toggles the pause status on a media object.
        """
        STOP = EffectCommands.STOP
        """
        the command stops the animation on a media object
        """
        STOPAUDIO = EffectCommands.STOPAUDIO
        """
        the command stops all currently running sound effects.
        """

__all__ = ['EffectCommands', 'EffectCommandsEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.util import SearchAlgorithms2 as SearchAlgorithms2
    if hasattr(SearchAlgorithms2, '_constants') and isinstance(SearchAlgorithms2._constants, dict):
        SearchAlgorithms2._constants['__ooo_ns__'] = 'com.sun.star.util'
        SearchAlgorithms2._constants['__ooo_full_ns__'] = 'com.sun.star.util.SearchAlgorithms2'
        SearchAlgorithms2._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global SearchAlgorithms2Enum
        ls = [f for f in dir(SearchAlgorithms2) if not callable(getattr(SearchAlgorithms2, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(SearchAlgorithms2, name)
        SearchAlgorithms2Enum = IntEnum('SearchAlgorithms2Enum', _dict)
    build_enum()
else:
    from ...lo.util.search_algorithms2 import SearchAlgorithms2 as SearchAlgorithms2

    class SearchAlgorithms2Enum(IntEnum):
        """
        Enum of Const Class SearchAlgorithms2

        Constants that define the search algorithm to be used with com.sun.star.util.SearchOptions2.SearchAlgorithms2.
        
        **since**
        
            LibreOffice 5.2
        """
        ABSOLUTE = SearchAlgorithms2.ABSOLUTE
        """
        Literal.
        """
        REGEXP = SearchAlgorithms2.REGEXP
        """
        Regular expression.
        """
        APPROXIMATE = SearchAlgorithms2.APPROXIMATE
        """
        Weighted Levenshtein Distance.
        """
        WILDCARD = SearchAlgorithms2.WILDCARD
        """
        Wildcards '*' and '?' An escape character is defined by setting com.sun.star.util.SearchOptions2.WildcardEscapeCharacter.
        """

__all__ = ['SearchAlgorithms2', 'SearchAlgorithms2Enum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from enum import Enum


class Priority(Enum):
    """
    Enum Class

    

    See Also:
        `API Priority <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#a315655b1bb5848c063491adffde62b15>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.Priority'
    __ooo_type_name__: str = 'enum'

    HIGH = 'HIGH'
    """
    High priority.
    """
    HIGHEST = 'HIGHEST'
    """
    Highest priority.
    """
    LOW = 'LOW'
    """
    Low priority.
    """
    LOWEST = 'LOWEST'
    """
    Lowest priority.
    """
    NORMAL = 'NORMAL'
    """
    Normal priority.
    """

__all__ = ['Priority']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart
from abc import abstractproperty
from .chart_data_point_properties import ChartDataPointProperties as ChartDataPointProperties_677c10bd

class ChartPieSegmentProperties(ChartDataPointProperties_677c10bd):
    """
    Service Class

    specifies all the properties for the graphic object of a pie segment.

    See Also:
        `API ChartPieSegmentProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartPieSegmentProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartPieSegmentProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SegmentOffset(self) -> int:
        """
        reflects the offset of a pie segment in percent of the radius.
        
        The default value for all the segments of a PieDiagram is 0. If you change this value from 0 to 100 the segment is pulled out from the center by its radius.
        
        Currently this property is supported by two dimensional pie diagrams only.
        """



__all__ = ['ChartPieSegmentProperties']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.rendering import PathCapType as PathCapType
    if hasattr(PathCapType, '_constants') and isinstance(PathCapType._constants, dict):
        PathCapType._constants['__ooo_ns__'] = 'com.sun.star.rendering'
        PathCapType._constants['__ooo_full_ns__'] = 'com.sun.star.rendering.PathCapType'
        PathCapType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global PathCapTypeEnum
        ls = [f for f in dir(PathCapType) if not callable(getattr(PathCapType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(PathCapType, name)
        PathCapTypeEnum = IntEnum('PathCapTypeEnum', _dict)
    build_enum()
else:
    from ...lo.rendering.path_cap_type import PathCapType as PathCapType

    class PathCapTypeEnum(IntEnum):
        """
        Enum of Const Class PathCapType

        These constants determine which shape to use for start or end of a stroked path.
        
        The start and end of stroked paths can have one out of several different shapes (which are, of course, only visible for strokes wider than one device pixel).
        
        **since**
        
            OOo 2.0
        """
        BUTT = PathCapType.BUTT
        """
        End the path at its start or end point, without any cap.
        """
        ROUND = PathCapType.ROUND
        """
        Extend the path with a half circle cap, diameter is the line width.
        """
        SQUARE = PathCapType.SQUARE
        """
        Extend the path with a rectangular cap, half the line width long.
        """

__all__ = ['PathCapType', 'PathCapTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...lo.scanner.scan_error import ScanError as ScanError
from ...lo.scanner.scanner_context import ScannerContext as ScannerContext
from ...lo.scanner.scanner_exception import ScannerException as ScannerException
from ...lo.scanner.scanner_manager import ScannerManager as ScannerManager
from ...lo.scanner.x_scanner_manager import XScannerManager as XScannerManager
from ...lo.scanner.x_scanner_manager2 import XScannerManager2 as XScannerManager2



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from ooo.oenv.env_const import UNO_NONE
from .native_number_xml_attributes import NativeNumberXmlAttributes as NativeNumberXmlAttributes_5e4f1070
from ..lang.locale import Locale as Locale_70d308fa
import typing


class NativeNumberXmlAttributes2(NativeNumberXmlAttributes_5e4f1070):
    """
    Struct Class

    Attributes describing a native number mode for a specific locale, stored in XML file format.
    
    Used later with XNativeNumberSupplier2.convertToXmlAttributes() and XNativeNumberSupplier2.convertFromXmlAttributes()
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API NativeNumberXmlAttributes2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1NativeNumberXmlAttributes2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.NativeNumberXmlAttributes2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.NativeNumberXmlAttributes2'
    """Literal Constant ``com.sun.star.i18n.NativeNumberXmlAttributes2``"""

    def __init__(self, Locale: typing.Optional[Locale_70d308fa] = UNO_NONE, Format: typing.Optional[str] = '', Style: typing.Optional[str] = '', Spellout: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Locale (Locale, optional): Locale value.
            Format (str, optional): Format value.
            Style (str, optional): Style value.
            Spellout (str, optional): Spellout value.
        """

        if isinstance(Locale, NativeNumberXmlAttributes2):
            oth: NativeNumberXmlAttributes2 = Locale
            self.Locale = oth.Locale
            self.Format = oth.Format
            self.Style = oth.Style
            self.Spellout = oth.Spellout
            return

        kargs = {
            "Locale": Locale,
            "Format": Format,
            "Style": Style,
            "Spellout": Spellout,
        }
        if kargs["Locale"] is UNO_NONE:
            kargs["Locale"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._spellout = kwargs["Spellout"]
        inst_keys = ('Spellout',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Spellout(self) -> str:
        """
        The format of the number string, for example, \"cardinal\", \"ordinal\" or \"ordinal-number\".
        """
        return self._spellout
    
    @Spellout.setter
    def Spellout(self, value: str) -> None:
        self._spellout = value


__all__ = ['NativeNumberXmlAttributes2']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..awt.mouse_event import MouseEvent as MouseEvent_8f430a5f
    from ..awt.x_control import XControl as XControl_7a9c098d
    from .x_submit_listener import XSubmitListener as XSubmitListener_d5950cce

class XSubmit(XInterface_8f010a43):
    """
    provides functionality to submit data from a component.
    
    Usually, this is used by com.sun.star.form.component.HTMLForms.
    
    See the HTML specification to learn about submitting forms.

    See Also:
        `API XSubmit <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XSubmit.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XSubmit'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XSubmit'

    @abstractmethod
    def addSubmitListener(self, aListener: 'XSubmitListener_d5950cce') -> None:
        """
        adds the specified listener to receive the \"approveSubmit\" event.
        """
    @abstractmethod
    def removeSubmitListener(self, aListener: 'XSubmitListener_d5950cce') -> None:
        """
        removes the specified listener.
        """
    @abstractmethod
    def submit(self, aControl: 'XControl_7a9c098d', aMouseEvt: 'MouseEvent_8f430a5f') -> None:
        """
        submits the component's data to a specified target.
        """

__all__ = ['XSubmit']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2


class DictionaryEventFlags(object):
    """
    Const Class

    flags used for the event type in dictionary events.
    
    These flags represent the type of events that a dictionary may broadcast.

    See Also:
        `API DictionaryEventFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryEventFlags.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.DictionaryEventFlags'
    __ooo_type_name__: str = 'const'

    ADD_ENTRY = 1
    """
    indicates that at least one entry has been added.
    """
    DEL_ENTRY = 2
    """
    indicates that at least one entry has been deleted.
    """
    CHG_NAME = 4
    """
    the dictionary's name has changed.
    """
    CHG_LANGUAGE = 8
    """
    the dictionary's language has changed.
    """
    ENTRIES_CLEARED = 16
    """
    all entries have been removed.
    """
    ACTIVATE_DIC = 32
    """
    used when the dictionary was activated.
    """
    DEACTIVATE_DIC = 64
    """
    used when the dictionary was deactivated.
    """

__all__ = ['DictionaryEventFlags']
